/*
    Tic-Tac-Toe 68k v1.0
    Copyright (C) 2001 John David Ratliff
    Questions or Comments: 
    	E-Mail: jdratlif@cs.indiana.edu
    	URL:	http://www.technoplaza.net 
    	
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// C Source File
// Created 6/17/2001; 1:08:39 AM
// Adapted for use with Tic-Tac-Toe 68k (Original from Checkers 68k)

#include "ttt.h"

#include <dialogs.h>
#include <kbd.h>
#include <system.h>
#include <compat.h>
#include <link.h>

// translation test var (TRUE if keypresses must be translated)
short int linkmode = NOTRANSLATE;

// display a dialog box with the error message
inline void fatal(const char *msg) {
	DlgMessage((char *)title,(char *)msg,BT_OK,BT_NONE);
}

short int getKey(short int wait) {
	unsigned short int key = 0, done = 0;
	void *kbq = kbd_queue();
	
	while (!done) {
		if (!wait || !OSdequeue(&key,kbq)) {
			done = 1;
		}
	}
	
	return (signed short int)key;
}

short int translateKey(short int keycode) {
	short int newkey;
	
	// translate the arrow keys
	switch (keycode) {
		case 337: newkey = 338; break;
		case 340: newkey = 344; break;
		case 338: newkey = 337; break;
		case 344: newkey = 340; break;
		
		// other keypresses shouldn't need translation
		default: newkey = keycode; break;
	}
	
	return newkey;
}

short int setupLink(short int side) {
	short int go = 1, mycalc = CALCULATOR;

	if (side == LINKO) {
		if (!recvCalc(mycalc)) {
			go = 0;
		}
		
		LIO_SendData(&mycalc,2);
	} else if (side == LINKX) {
		LIO_SendData(&mycalc,2);
		
		if (!recvCalc(mycalc)) {
			go = 0;
		}
	}
	
	return go;
}

short int recvCalc(short int mycalc) {
	short int calc = -1;

	// wait for link to receive data
	if (LIO_RecvData(&calc,2,LINKWAIT * 2) != LINKOK) {
		return 0;
	} else {
		if (calc == mycalc) {
			linkmode = NOTRANSLATE;
		} else {
			linkmode = TRANSLATE;
		}
	}
	
	return 1;
}
